@@ -1,7 +1,8 @@
 import re
 
 PATTERN_APRS = re.compile(r"^(?P<callsign>.+?)>(?P<dstcall>[A-Z0-9]+),((?P<relay>[A-Za-z0-9]+)\*)?.*,(?P<receiver>.+?):(?P<aprs_type>(.))(?P<aprs_body>.*)$")
-PATTERN_APRS_POSITION = re.compile(r"^(?P<time>(([0-1]\d|2[0-3])[0-5]\d[0-5]\dh|([0-2]\d|3[0-1])([0-1]\d|2[0-3])[0-5]\dz))(?P<latitude>9000\.00|[0-8]\d{3}\.\d{2})(?P<latitude_sign>N|S)(?P<symbol_table>.)(?P<longitude>18000\.00|1[0-7]\d{3}\.\d{2}|0\d{4}\.\d{2})(?P<longitude_sign>E|W)(?P<symbol>.)(?P<course_extension>(?P<course>\d{3})/(?P<ground_speed>\d{3}))?/(A=(?P<altitude>(-\d{5}|\d{6})))?(?P<pos_extension>\s!W((?P<latitude_enhancement>\d)(?P<longitude_enhancement>\d))!)?(?:\s(?P<comment>.*))?$")
+PATTERN_APRS_POSITION = re.compile(r"^(?P<time>(([0-1]\d|2[0-3])[0-5]\d[0-5]\dh|([0-2]\d|3[0-1])([0-1]\d|2[0-3])[0-5]\dz))(?P<latitude>9000\.00|[0-8]\d{3}\.\d{2})(?P<latitude_sign>N|S)(?P<symbol_table>.)(?P<longitude>18000\.00|1[0-7]\d{3}\.\d{2}|0\d{4}\.\d{2})(?P<longitude_sign>E|W)(?P<symbol>.)(?P<course_extension>(?P<course>\d{3})/(?P<ground_speed>\d{3}))?(/A=(?P<altitude>(-\d{5}|\d{6})))?(?P<pos_extension>\s!W((?P<latitude_enhancement>\d)(?P<longitude_enhancement>\d))!)?(?:\s(?P<comment>.*))?$")
+PATTERN_APRS_POSITION_WEATHER = re.compile(r"^(?P<time>(([0-1]\d|2[0-3])[0-5]\d[0-5]\dh|([0-2]\d|3[0-1])([0-1]\d|2[0-3])[0-5]\dz))(?P<latitude>9000\.00|[0-8]\d{3}\.\d{2})(?P<latitude_sign>N|S)(?P<symbol_table>.)(?P<longitude>18000\.00|1[0-7]\d{3}\.\d{2}|0\d{4}\.\d{2})(?P<longitude_sign>E|W)(?P<symbol>.)(?P<wind_direction>(\d{3}|\.{3}))/(?P<wind_speed>(\d{3}|\.{3}))g(?P<wind_speed_peak>(\d{3}|\.{3}))t(?P<temperature>(\d{3}|\.{3}))(h(?P<humidity>\d{2}))?(b(?P<barometric_pressure>\d{5}))?(?:\s(?P<comment>.*))?$")
 PATTERN_APRS_STATUS = re.compile(r"^(?P<time>(([0-1]\d|2[0-3])[0-5]\d[0-5]\dh|([0-2]\d|3[0-1])([0-1]\d|2[0-3])[0-5]\dz))\s(?P<comment>.*)$")
 
 PATTERN_SERVER = re.compile(r"^# aprsc (?P<version>[a-z0-9\.\-]+) (?P<timestamp>\d+ [A-Za-z]+ \d+ \d{2}:\d{2}:\d{2} GMT) (?P<server>[A-Z0-9]+) (?P<ip_address>\d+\.\d+\.\d+\.\d+):(?P<port>\d+)$")
@@ -12,7 +13,7 @@ PATTERN_FANET_POSITION_COMMENT = re.compile(r"""
 """, re.VERBOSE | re.MULTILINE)
 
 PATTERN_FANET_STATUS_COMMENT = re.compile(r"""
-    (?:(Name=\"(?P<user_name>[^\"]*)\")\s?)?
+    (?:(Name=\"(?P<fanet_name>[^\"]*)\")\s?)?
     (?:(?P<signal_quality>[\d.]+?)dB\s?)?
     (?:(?P<frequency_offset>[+-][\d.]+?)kHz\s?)?
     (?:(?P<error_count>\d+)e\s?)?
@@ -33,7 +34,7 @@ PATTERN_FLARM_POSITION_COMMENT = re.compile(r"""
 """, re.VERBOSE | re.MULTILINE)
 
 PATTERN_LT24_POSITION_COMMENT = re.compile(r"""
-    id(?P<id>\d+)\s
+    id(?P<lt24_id>\d+)\s
     (?P<climb_rate>[+-]\d+)fpm\s
     (?P<source>.+)
 """, re.VERBOSE | re.MULTILINE)
@@ -45,19 +46,19 @@ PATTERN_NAVITER_POSITION_COMMENT = re.compile(r"""
 """, re.VERBOSE | re.MULTILINE)
 
 PATTERN_SKYLINES_POSITION_COMMENT = re.compile(r"""
-    id(?P<id>\d+)\s
+    id(?P<skylines_id>\d+)\s
     (?P<climb_rate>[+-]\d+)fpm
 """, re.VERBOSE | re.MULTILINE)
 
 PATTERN_SPIDER_POSITION_COMMENT = re.compile(r"""
-    id(?P<id>[\d-]+)\s
+    id(?P<spider_id>[\d-]+)\s
     (?P<signal_power>[+-]\d+)dB\s
-    (?P<spider_id>[A-Z0-9]+)\s
+    (?P<spider_registration>[A-Z0-9]+)\s
     (?P<gps_quality>.+)
 """, re.VERBOSE | re.MULTILINE)
 
 PATTERN_SPOT_POSITION_COMMENT = re.compile(r"""
-    id(?P<id>[\d-]+)\s
+    id(?P<spot_id>[\d-]+)\s
     (?P<model>SPOT[A-Z\d]+)\s
     (?P<status>[A-Z]+)
 """, re.VERBOSE | re.MULTILINE)
@@ -178,11 +179,12 @@ PATTERN_RECEIVER_BEACON = re.compile(r"""
     \s)?
     CPU:(?P<cpu_load>[\d.]+)\s
     RAM:(?P<ram_free>[\d.]+)/(?P<ram_total>[\d.]+)MB\s
-    NTP:(?P<ntp_offset>[\d.]+)ms/(?P<ntp_correction>[+-][\d.]+)ppm\s
+    NTP:(?P<ntp_offset>[\d.]+)ms/(?P<ntp_correction>[+-][\d.]+)ppm\s?
     (?:(?P<voltage>[\d.]+)V\s)?
     (?:(?P<amperage>[\d.]+)A\s)?
     (?:(?P<cpu_temperature>[+-][\d.]+)C\s*)?
     (?:(?P<visible_senders>\d+)/(?P<senders>\d+)Acfts\[1h\]\s*)?
+    (Lat\:(?P<latency>\d+\.\d+)s\s*)?
     (?:RF:
         (?:
             (?P<rf_correction_manual>[+-][\d]+)
