@@ -8,7 +8,7 @@ class TestStringMethods(unittest.TestCase):
     def test_position_comment(self):
         message = LT24Parser().parse_position("id25387 +123fpm GPS")
 
-        self.assertEqual(message['address'], "25387")
+        self.assertEqual(message['lt24_id'], "25387")
         self.assertAlmostEqual(message['climb_rate'], 123 * FPM_TO_MS, 2)
         self.assertEqual(message['source'], 'GPS')
 
