@@ -8,7 +8,7 @@ class TestStringMethods(unittest.TestCase):
     def test_position_comment(self):
         message = SkylinesParser().parse_position("id2816 -015fpm")
 
-        self.assertEqual(message['address'], "2816")
+        self.assertEqual(message['skylines_id'], "2816")
         self.assertAlmostEqual(message['climb_rate'], -15 * FPM_TO_MS, 2)
 
 
