@@ -7,9 +7,9 @@ class TestStringMethods(unittest.TestCase):
     def test_position_comment(self):
         message = SpiderParser().parse_position("id300234060668560 +30dB K23W 3D")
 
-        self.assertEqual(message['address'], "300234060668560")
+        self.assertEqual(message['spider_id'], "300234060668560")
         self.assertEqual(message['signal_power'], 30)
-        self.assertEqual(message['spider_id'], "K23W")
+        self.assertEqual(message['spider_registration'], "K23W")
         self.assertEqual(message['gps_quality'], "3D")
 
 
